@@ -34,9 +34,11 @@
 #' \code{\link[nomclust]{iof}},
 #' \code{\link[nomclust]{lin}},
 #' \code{\link[nomclust]{lin1}},
-#' \code{\link[nomclust]{morlini}} 
+#' \code{\link[nomclust]{morlini}}, 
 #' \code{\link[nomclust]{of}},
-#' \code{\link[nomclust]{sm}}.
+#' \code{\link[nomclust]{sm}},
+#' \code{\link[nomclust]{ve}},
+#' \code{\link[nomclust]{vm}}.
 #'
 #' @author Zdenek Sulc. \cr Contact: \email{zdenek.sulc@@vse.cz}
 #' 
@@ -78,8 +80,8 @@ good1 <- function(data) {
   agreement <- vector(mode="numeric", length=s)
   good1 <- matrix(data=0,nrow=r,ncol=r)
   
-  for (i in 1:r) {
-    for (j in 1:r) {
+  for (i in 1:(r-1)) {
+    for (j in (1+i):r) {
       for (k in 1:s) {
         c <- data[i,k]
         if (data[i,k] == data[j,k]) {
@@ -95,6 +97,7 @@ good1 <- function(data) {
       }
       else {
         good1[i,j] <- 1-1/s*(sum(agreement))
+        good1[j,i] <- good1[i,j]
       }
     }
   }
