@@ -37,7 +37,9 @@
 #' \code{\link[nomclust]{lin1}},
 #' \code{\link[nomclust]{morlini}},
 #' \code{\link[nomclust]{of}},
-#' \code{\link[nomclust]{sm}}.
+#' \code{\link[nomclust]{sm}},
+#' \code{\link[nomclust]{ve}},
+#' \code{\link[nomclust]{vm}}.
 #'
 #' @author Zdenek Sulc. \cr Contact: \email{zdenek.sulc@@vse.cz}
 #' 
@@ -78,8 +80,8 @@ good3 <- function(data) {
   agreement <- vector(mode="numeric", length=s)
   good3 <- matrix(data=0,nrow=r,ncol=r)
   
-  for (i in 1:r) {
-    for (j in 1:r) {
+  for (i in 1:(r-1)) {
+    for (j in (1+i):r) {
       for (k in 1:s) {
         c <- data[i,k]
         if (data[i,k] == data[j,k]) {
@@ -94,6 +96,7 @@ good3 <- function(data) {
       }
       else {
         good3[i,j] <- 1-1/s*(sum(agreement))
+        good3[j,i] <- good3[i,j]
       }
     }
   }
