@@ -45,7 +45,9 @@
 #' \code{\link[nomclust]{lin}},
 #' \code{\link[nomclust]{morlini}},
 #' \code{\link[nomclust]{of}},
-#' \code{\link[nomclust]{sm}}.
+#' \code{\link[nomclust]{sm}},
+#' \code{\link[nomclust]{ve}},
+#' \code{\link[nomclust]{vm}}.
 #'
 #' @author Zdenek Sulc. \cr Contact: \email{zdenek.sulc@@vse.cz}
 #' 
@@ -91,8 +93,8 @@ lin1 <- function(data) {
   lin1 <- matrix(data=0,nrow=r,ncol=r)
   weights <- vector(mode="numeric", length=s)
 
-  for (i in 1:r) {
-    for (j in 1:r) {
+  for (i in 1:(r-1)) {
+    for (j in (1+i):r) {
       for (k in 1:s) {
         c <- data[i,k]
         d <- data[j,k]
@@ -115,6 +117,7 @@ lin1 <- function(data) {
         }
       }
       lin1[i,j] <- 1/(1/sum(weights)*(sum(agreement))) - 1
+      lin1[j,i] <- lin1[i,j]
     }
   }
   lin1[lin1 == -Inf] <- max(lin1) + 1
